@@ -16,9 +16,9 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id: build-defs.h.in 292156 2009-12-15 11:17:47Z jani $ */
+/* $Id: build-defs.h.in 310307 2011-04-18 09:50:32Z bjori $ */
 
-#define CONFIGURE_COMMAND " './configure'  '--prefix=/opt/php-5.2.17' '--with-config-file-path=/opt/php-5.2.17/etc' '--with-apxs2=/opt/httpd/bin/apxs' '--with-pear' '--enable-zend-multibyte' '--enable-mbstring' '--enable-mbregex' '--enable-exif' '--enable-soap' '--enable-sockets' '--with-zlib' '--enable-sysvmsg' '--enable-sysvsem' '--enable-sysvshm' '--enable-shmop' '--with-readline' '--enable-ftp' '--with-openssl' '--with-pgsql' '--with-pdo-pgsql=/opt/pgsql' '--enable-sqlite-utf8'"
+#define CONFIGURE_COMMAND " './configure'  '--prefix=/opt/php-5.3.9' '--with-config-file-path=/opt/php-5.3.9/etc' '--with-config-file-scan-dir=/opt/php-5.3.9/etc/php.d' '--with-apxs2=/opt/httpd/bin/apxs' '--with-pear' '--enable-zend-multibyte' '--enable-mbstring' '--enable-mbregex' '--enable-exif' '--enable-soap' '--enable-sockets' '--with-zlib' '--enable-sysvmsg' '--enable-sysvsem' '--enable-sysvshm' '--enable-shmop' '--with-readline' '--enable-ftp' '--with-openssl' '--with-pgsql' '--with-pdo-pgsql=/opt/pgsql' '--enable-sqlite-utf8'"
 #define PHP_ADA_INCLUDE		""
 #define PHP_ADA_LFLAGS		""
 #define PHP_ADA_LIBS		""
@@ -53,7 +53,7 @@
 #define PHP_ODBC_TYPE		""
 #define PHP_OCI8_SHARED_LIBADD 	""
 #define PHP_OCI8_DIR			""
-#define PHP_OCI8_VERSION		""
+#define PHP_OCI8_ORACLE_VERSION		""
 #define PHP_ORACLE_SHARED_LIBADD 	"@ORACLE_SHARED_LIBADD@"
 #define PHP_ORACLE_DIR				"@ORACLE_DIR@"
 #define PHP_ORACLE_VERSION			"@ORACLE_VERSION@"
@@ -75,16 +75,17 @@
 #define PHP_LDAP_LIBS		""
 #define PHP_BIRDSTEP_INCLUDE     ""
 #define PHP_BIRDSTEP_LIBS        ""
-#define PEAR_INSTALLDIR         "/opt/php-5.2.17/lib/php"
-#define PHP_INCLUDE_PATH	".:/opt/php-5.2.17/lib/php"
-#define PHP_EXTENSION_DIR       "/opt/php-5.2.17/lib/php/extensions/no-debug-non-zts-20060613"
-#define PHP_PREFIX              "/opt/php-5.2.17"
-#define PHP_BINDIR              "/opt/php-5.2.17/bin"
-#define PHP_SBINDIR             "/opt/php-5.2.17/sbin"
-#define PHP_LIBDIR              "/opt/php-5.2.17/lib/php"
-#define PHP_DATADIR             "/opt/php-5.2.17/share/php"
-#define PHP_SYSCONFDIR          "/opt/php-5.2.17/etc"
-#define PHP_LOCALSTATEDIR       "/opt/php-5.2.17/var"
-#define PHP_CONFIG_FILE_PATH    "/opt/php-5.2.17/etc"
-#define PHP_CONFIG_FILE_SCAN_DIR    ""
+#define PEAR_INSTALLDIR         "/opt/php-5.3.9/lib/php"
+#define PHP_INCLUDE_PATH	".:/opt/php-5.3.9/lib/php"
+#define PHP_EXTENSION_DIR       "/opt/php-5.3.9/lib/php/extensions/no-debug-non-zts-20090626"
+#define PHP_PREFIX              "/opt/php-5.3.9"
+#define PHP_BINDIR              "/opt/php-5.3.9/bin"
+#define PHP_SBINDIR             "/opt/php-5.3.9/sbin"
+#define PHP_MANDIR              "/opt/php-5.3.9/man"
+#define PHP_LIBDIR              "/opt/php-5.3.9/lib/php"
+#define PHP_DATADIR             "/opt/php-5.3.9/share/php"
+#define PHP_SYSCONFDIR          "/opt/php-5.3.9/etc"
+#define PHP_LOCALSTATEDIR       "/opt/php-5.3.9/var"
+#define PHP_CONFIG_FILE_PATH    "/opt/php-5.3.9/etc"
+#define PHP_CONFIG_FILE_SCAN_DIR    "/opt/php-5.3.9/etc/php.d"
 #define PHP_SHLIB_SUFFIX        "so"
