@@ -12,7 +12,7 @@
  * @author     Tomas V.V.Cox <cox@idecnet.com>
  * @copyright  1997-2009 The Authors
  * @license    http://opensource.org/licenses/bsd-license.php New BSD License
- * @version    CVS: $Id: pearcmd.php 296932 2010-03-27 15:13:06Z dufuz $
+ * @version    CVS: $Id: pearcmd.php 313023 2011-07-06 19:17:11Z dufuz $
  * @link       http://pear.php.net/package/PEAR
  */
 
@@ -25,8 +25,8 @@ define('PEAR_IGNORE_BACKTRACE', 1);
 /**
  * @nodep Gtk
  */
-if ('/opt/php-5.2.17/lib/php' != '@'.'include_path'.'@') {
-    ini_set('include_path', '/opt/php-5.2.17/lib/php');
+if ('/opt/php-5.3.9/lib/php' != '@'.'include_path'.'@') {
+    ini_set('include_path', '/opt/php-5.3.9/lib/php');
     $raw = false;
 } else {
     // this is a raw, uninstalled pear, either a cvs checkout, or php distro
@@ -43,7 +43,7 @@ ob_implicit_flush(true);
 $_PEAR_PHPDIR = '#$%^&*';
 set_error_handler('error_handler');
 
-$pear_package_version = "1.9.1";
+$pear_package_version = "1.9.4";
 
 require_once 'PEAR.php';
 require_once 'PEAR/Frontend.php';
@@ -343,6 +343,10 @@ function usage($error = null, $helpsubject = null)
     }
     fputs($stdout, "$put\n");
     fclose($stdout);
+
+    if ($error === null) {
+        exit(0);
+    }
     exit(1);
 }
 
